@@ -1,4 +1,4 @@
-tabPanel("exchangesStack",
+tabPanel(textOutput("label_tab_exchanges"),
          fluidRow(
            column(12,
                   conditionalPanel(condition = "output.have_data",
@@ -6,11 +6,11 @@ tabPanel("exchangesStack",
                                                     uiOutput("exchangesStack_ui")
                                    ),
                                    conditionalPanel(condition = "output.have_data_links === false",
-                                                    h3("No links imported")
+                                                    h3(textOutput("no_links"))
                                    )
                   ),
                   conditionalPanel(condition = "output.have_data === false",
-                                   h3("No data imported")
+                                   h3(textOutput("no_data_2"))
                   )
            )
          )
